EpubTextContentFile class

Inheritance

Constructors

EpubTextContentFile()

Properties

Content ↔ String?
getter/setter pair
ContentMimeType ↔ String?
getter/setter pairinherited
ContentType ↔ EpubContentType?
getter/setter pairinherited
FileName ↔ String?
getter/setter pairinherited
hashCode → int
The hash code for this object.
no setteroverride
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
override